==> nextcloud-13.0.1.tgz: nextcloud/apps/survey_client/l10n/ko.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "사용량 통계 조사",
    "Sent on: {on}" : "보낸 날짜: {on}",
    "An error occurred while sending your report." : "보고서를 보내는 중 오류가 발생했습니다.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "앱 목록<em>(개별 앱의 이름, 버전, 활성화 상태)</em>",
    "Database environment <em>(type, version, database size)</em>" : "데이터베이스 환경<em>(종류, 버전, 데이터베이스 크기)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "암호화 정보<em>(활성화 여부, 기본 모듈)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "공유 개수<em>(형식 및 권한별)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP 환경<em>(버전, 메모리 제한, 최대 실행 시간, 최대 파일 크기)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "서버 인스턴스 정보<em>(버전, memcache 사용, 잠금/미리 보기/아바타 상태)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "통계<em>(파일, 사용자, 종류별 저장소, 댓글, 태그 개수)</em>",
    "Help improve Nextcloud" : "Nextcloud 기능 개선 돕기",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Nextcloud 개선을 돕기 위해서 설치 및 사용 통계를 익명으로 전송하시겠습니까? 관리자 설정에서 언제든지 비활성화할 수 있습니다.",
    "Not now" : "지금은 하지 않음",
    "Send usage" : "통계 보내기",
    "Never" : "절대 보내지 않음",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Nextcloud 개선을 돕기 위해서 설치 및 사용 통계를 익명으로 전송할 수 있습니다.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "귀하의 개인 정보는 소중합니다. 통계 정보는 기본적으로 전송하지 않으며, 전송하기로 결정한 경우에는 우선 익명화 절차를 거치고 공유할 항목을 선택할 수 있습니다. 통계 정보를 수신하면 이전 정보는 삭제됩니다. 빈 통계 정보를 전송하면 서버에 저장된 모든 데이터를 삭제합니다",
    "Send new report now" : "지금 새 보고서 보내기",
    "Send usage survey monthly" : "월별 사용 통계 보내기",
    "Data to send" : "보낼 데이터",
    "Last report" : "마지막 보고",
    "Sent on: %s" : "보낸 날짜: %s",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "앱 목록<em>(개별 앱의 이름, 버전, 활성화 상태)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "서버 인스턴스 정보<em>(버전, memcache 사용, 잠금/미리 보기/아바타 상태)</em>",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Nextcloud 개선을 돕기 위해서 설치 및 사용 통계를 익명으로 전송할 수 있습니다.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "귀하의 개인 정보는 소중합니다. 통계 정보는 기본적으로 전송하지 않으며, 전송하기로 결정한 경우에는 우선 익명화 절차를 거치고 공유할 항목을 선택할 수 있습니다. 통계 정보를 수신하면 이전 정보는 삭제됩니다. 빈 통계 정보를 전송하면 서버에 저장된 모든 데이터를 삭제합니다"
},
"nplurals=1; plural=0;");

==> nextcloud-22.2.6.tgz: nextcloud/apps/survey_client/l10n/ko.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "마지막 보고서 전송: {on}",
    "An error occurred while sending your report." : "보고서를 보내는 중 오류가 발생했습니다.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "앱 목록<em>(개별 앱의 이름, 버전, 활성화 상태)</em>",
    "Database environment <em>(type, version, database size)</em>" : "데이터베이스 환경<em>(종류, 버전, 데이터베이스 크기)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "암호화 정보<em>(활성화 여부, 기본 모듈)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "공유 개수<em>(형식 및 권한별)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP 환경<em>(버전, 메모리 제한, 최대 실행 시간, 최대 파일 크기)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "서버 인스턴스 정보<em>(버전, memcache 사용, 잠금/미리 보기/아바타 상태)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "통계<em>(파일 개수, 사용자 수, 종류별 저장소 개수, 댓글과 태그 개수)</em>",
    "Usage survey" : "사용량 통계 조사",
    "Help improve Nextcloud" : "Nextcloud 기능 개선 돕기",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Nextcloud 개선을 돕기 위해서 설치 및 사용 통계를 익명으로 전송하시겠습니까? 관리자 설정에서 언제든지 비활성화할 수 있습니다.",
    "Not now" : "지금은 하지 않음",
    "Send usage" : "통계 보내기",
    "Never" : "절대 보내지 않음",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Nextcloud에 익명 사용량 통계를 전송하여 기능 개선을 돕습니다.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Nextcloud에 익명 사용량 통계를 전송하여 기능 개선을 돕습니다. Nextcloud에\n        전송할 데이터에 대한 통제권은 항상 여러분에게 있으며 언제든지 통계 전송을\n        취소할 수 있습니다.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Nextcloud 개선을 돕기 위해서 설치 및 사용 통계를 익명으로 전송할 수 있습니다.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "귀하의 개인 정보는 소중합니다. 통계 정보는 기본적으로 전송하지 않으며, 전송하기로 결정한 경우에는 우선 익명화 절차를 거치고 공유할 항목을 선택할 수 있습니다. 통계 정보를 수신하면 이전 정보는 삭제됩니다. 빈 통계 정보를 전송하면 서버에 저장된 모든 데이터를 삭제합니다",
    "Send new report now" : "지금 새 보고서 보내기",
    "Send usage survey monthly" : "월별 사용 통계 보내기",
    "Data to send" : "보낼 데이터",
    "Last report sent on: %s" : "마지막 보고서 전송: %s",
    "Last report" : "마지막 보고"
},
"nplurals=1; plural=0;");
